#
# spec file for package fooyin
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fooyin
Version:        0.5.3
Release:        1.2
Summary:        A customisable music player built with Qt
License:        GPL-3.0-only
URL:            https://github.com/ludouzi/%{name}
Source:         https://github.com/ludouzi/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  c++_compiler
BuildRequires:  hicolor-icon-theme
BuildRequires:  qt6-base-devel
BuildRequires:  cmake(KDSingleApplication-qt6)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6DBus)
BuildRequires:  cmake(Qt6Linguist)
BuildRequires:  cmake(Qt6LinguistTools)
BuildRequires:  cmake(Qt6OpenGLWidgets)
BuildRequires:  cmake(Qt6Svg)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(taglib)
BuildRequires:  pkgconfig(xkbcommon)

%description
fooyin is a Qt6 music player built around customisation. It offers a
growing list of widgets to manage and play a local music collection.
It is extendable through the use of plugins, and many widgets make
use of FooScript to offer an even deeper level of control.

%prep
%autosetup -p1

%build
%cmake
%cmake_build

%install
%cmake_install
# No header files were installed, so... no point in keeping the
# component libraries' devel files.
rm -fv %{buildroot}/%{_libdir}/fooyin/*.so

%files
%license COPYING
%doc README.md
%{_bindir}/%{name}
%{_datadir}/applications/*
%{_datadir}/doc/%{name}
%{_datadir}/metainfo/*
%{_datadir}/icons/hicolor/*/apps/org.%{name}.%{name}.*
%{_datadir}/%{name}
%{_libdir}/%{name}/

%changelog
* Mon Jul  8 2024 Julius Enriquez <win8linux@gmail.com>
- Update to upstream 0.5.3
  * Fixes
  * LibraryScanner
  * Fix reading file properties for external files
  * Fix reading duration for cue tracks
  * Playlist: Fix start playback on send to new playlist failing
- Release notes for interim release 0.5.2 can be found here:
  https://github.com/fooyin/fooyin/releases/tag/v0.5.2
* Sun Jun 30 2024 Julius Enriquez <win8linux@gmail.com>
- Update to upstream 0.5.1
  * Improvements
  * Playback
  * Add option to silently continue playback if track unavailable
  * Show message box for ALSA device errors
  * Library Tree: Make animation of expand/collapse configurable
  * Volume Control: Add slider mode
  * Fixes
  * Playlist
  * Fix unscrollable view when changing playlist
  * Fix selection playlists refreshing during library scans
  * Engine: Fix silence when resuming from a stopped state with fading enabled
  * ExpandedTreeView: Stop autoscrolling to selection if partly visible
  * Filters: Fix restoring selection on track update
  * Library Tree: Fix text colour for playing row
  * Scripting: Fix usage of custom tags
- Release notes for interim release 0.5.0 can be found here:
  https://github.com/ludouzi/fooyin/releases/tag/v0.5.0
* Thu Jun  6 2024 Julius Enriquez <win8linux@gmail.com>
- Update to upstream release 0.4.5
  * Fixes
  * Fix playback on startup if current output not found
  * Fix pause not pausing playback position
- Release notes for interim release 0.4.4 can be found here:
  https://github.com/ludouzi/fooyin/releases/tag/v0.4.4
* Wed May 29 2024 Julius Enriquez <win8linux@gmail.com>
- Update to new upstream release 0.4.3
  * Improvements
  * Interface
  * Support changing volume by scrolling on volume icon
  * Add options to control appearance of tool buttons
  * Add options to override margins, splitter handle sizes
  * Make quick setup dialog modal
  * Playlist
  * Add channels column
  * Add last modified column
  * Improve performance when updating playback statistics
  * WaveBar
  * Add optional labels
  * Improve behaviour when seeking
  * Fixes
  * Refer to the upstream release notes for more details on fixes: https://github.com/ludouzi/fooyin/releases/tag/v0.4.3
- Removed QCoro dependency
  * See https://github.com/ludouzi/fooyin/commit/c5aa3620c2d78a70e3d10d06d8fb0ed6ce4cb041
- Icon name changed to reverse DNS format
  * Part of a commit to use more reverse DNS: https://github.com/ludouzi/fooyin/commit/fab7933ced4347d7593c1ea378ebe56081d930a5
* Sun May 26 2024 Julius Enriquez <win8linux@gmail.com>
- Working spec file
* Thu May 23 2024 Julius Enriquez <win8linux@gmail.com>
- Initial spec file
